@@ -10,8 +10,8 @@
 #define OKTETA_BYTEARRAYCHANGE_HPP
 
 // lib
-#include <okteta/oktetacore_export.hpp>
-#include <okteta/arraychangemetrics.hpp>
+#include "oktetacore_export.hpp"
+#include "arraychangemetrics.hpp"
 // Qt
 #include <QByteArray>
 
@@ -28,6 +28,11 @@ class OKTETACORE_EXPORT ByteArrayChange
 public:
     ByteArrayChange();
     explicit ByteArrayChange(const ArrayChangeMetrics& metrics, const QByteArray& data = QByteArray());
+    ByteArrayChange(const ByteArrayChange&) = default;
+
+    ~ByteArrayChange() = default;
+
+    ByteArrayChange& operator=(const ByteArrayChange&) = default;
 
 public:
     const ArrayChangeMetrics& metrics() const;
