@@ -30,12 +30,15 @@ public:
 
     static const QStringList& codecNames();
 
-protected:
-    TextCharCodec(QTextCodec* textCodec);
-
 public:
+    TextCharCodec(const TextCharCodec&) = delete;
     ~TextCharCodec() override;
 
+    TextCharCodec& operator=(const TextCharCodec&) = delete;
+
+protected:
+    explicit TextCharCodec(QTextCodec* textCodec);
+
 public: // CharCodec API
     Character decode(Byte byte) const override;
     bool encode(Byte* byte, const QChar& _char) const override;
