@@ -26,7 +26,7 @@ public:
     explicit Dropper(AbstractByteArrayView* view);
     Dropper(const Dropper&) = delete;
 
-    ~Dropper();
+    ~Dropper() = default; // trivial
 
     Dropper& operator=(const Dropper&) = delete;
 
@@ -52,6 +52,17 @@ private:
     bool mIsActive : 1;
 };
 
+inline Dropper::Dropper(AbstractByteArrayView* view)
+    : mByteArrayView(view)
+    , mIsActive(false)
+{
+}
+
+inline bool Dropper::isActive() const
+{
+    return mIsActive;
+}
+
 }
 
 #endif
