@@ -29,7 +29,6 @@ MouseNavigator::MouseNavigator(AbstractByteArrayView* view, AbstractMouseControl
     : AbstractMouseController(view, parent)
     , mLMBPressed(false)
     , mInLMBDoubleClick(false)
-    , mInDnD(false)
     , mDragStartPossible(false)
 {
     mScrollTimer = new QTimer(this);
@@ -334,3 +333,5 @@ void MouseNavigator::startDrag()
 }
 
 }
+
+#include "moc_mousenavigator.cpp"
