@@ -39,7 +39,7 @@ static constexpr int DefaultNoOfBytesPerLine =  16;
 
 static constexpr int DefaultBinaryGapWidth = 1;
 
-static constexpr int InsertCursorWidth = 2;
+static constexpr int InsertCursorWidth = 2; ///< Unused
 
 static constexpr bool DefaultShowingNonprinting = false;
 static constexpr QChar DefaultSubstituteChar =  QLatin1Char('.');
