@@ -24,9 +24,12 @@ protected:
     explicit AbstractTypeCodec(const QString& name);
 
 public:
-    AbstractTypeCodec() = delete;
+    AbstractTypeCodec(const AbstractTypeCodec&) = delete;
+
     virtual ~AbstractTypeCodec();
 
+    AbstractTypeCodec& operator=(const AbstractTypeCodec&) = delete;
+
 public: // API to be implemented
     virtual QVariant value(const PODData& data, int* byteCount) const = 0;
     virtual QByteArray valueToBytes(const QVariant& value) const = 0;
