@@ -56,7 +56,7 @@ bool DummyDataInformation::setData(const QVariant& v, Okteta::AbstractByteArrayM
     return parentHelper()->setChildData(mIndex, v, out, addr, remaining, offset);
 }
 
-qint64 DummyDataInformation::readData(Okteta::AbstractByteArrayModel*, Okteta::Address,
+qint64 DummyDataInformation::readData(const Okteta::AbstractByteArrayModel*, Okteta::Address,
                                       BitCount64, quint8*)
 {
     Q_ASSERT(false); // should never be called
