@@ -91,7 +91,7 @@ QString Utf8StringData::completeString(bool skipInvalid) const
     return QString(data.constData(), i);
 }
 
-qint64 Utf8StringData::read(Okteta::AbstractByteArrayModel* input, Okteta::Address address,
+qint64 Utf8StringData::read(const Okteta::AbstractByteArrayModel* input, Okteta::Address address,
                             BitCount64 bitsRemaining)
 {
     const int oldSize = count();
