@@ -23,12 +23,14 @@ class QScriptValue;
 
 class ScriptHandler
 {
-    Q_DISABLE_COPY(ScriptHandler)
-
 public:
     ScriptHandler(QScriptEngine* engine, TopLevelDataInformation* topLevel);
+    ScriptHandler(const ScriptHandler&) = delete;
+
     virtual ~ScriptHandler();
 
+    ScriptHandler& operator=(const ScriptHandler&) = delete;
+
 public:
     void validateData(DataInformation* data);
     /** The pointer may be changed while updating, CHECK AS SOON AS FUNCTION RETURNS! */
