@@ -17,9 +17,10 @@
 // Kasten core
 #include <Kasten/AbstractTool>
 // Okteta core
-#include <Okteta/Address>
+#include <Okteta/AddressRange>
 
 class QModelIndex;
+class QByteArray;
 
 class DataInformation;
 
@@ -56,6 +57,9 @@ public:
     /** check if there is any ByteArrayModel available to lock the structure */
     bool canStructureBeLocked(const QModelIndex& idx) const;
     bool isFileLoaded() const;
+    QByteArray bytes(const DataInformation* data) const;
+
+    void selectBytesInView(const QModelIndex& idx);
 
     // interface for model
     QVariant headerData(int column, int role) const;
@@ -67,7 +71,6 @@ Q_SIGNALS:
     void dataChanged(int row, void* data); // actually a DataInformation*
     void dataCleared();
     void byteOrderChanged();
-    void cursorIndexChanged();
     void byteArrayModelChanged(Okteta::AbstractByteArrayModel* model);
     /** items are inserted before @p startIndex */
     void childrenAboutToBeInserted(DataInformation* sender, uint startIndex, uint endIndex);
@@ -95,12 +98,14 @@ private Q_SLOTS:
 
 private:
     Okteta::Address startAddress(const TopLevelDataInformation* data) const;
+    Okteta::AddressRange dataRange(const DataInformation* data) const;
 
 private:
     // source
     ByteArrayView* mByteArrayView = nullptr;
     Okteta::AbstractByteArrayModel* mByteArrayModel = nullptr;
     Okteta::Address mCursorIndex = 0;
+    Okteta::ArrayChangeMetricsList mArrayChangesWhileWriting;
 
     // settings
     QSysInfo::Endian mByteOrder;
@@ -109,6 +114,7 @@ private:
     TopLevelDataInformation::List mInvalidData;
     bool mWritingData : 1;
     bool mCurrentItemDataChanged : 1;
+    bool mIsStructureMarked : 1;
 };
 
 }
