@@ -12,8 +12,7 @@
 // Kasten core
 #include <Kasten/AbstractModelDataGenerator>
 // Qt
-#include <QObject>
-#include <QString>
+#include <QByteArray>
 
 namespace Kasten {
 
