@@ -20,6 +20,9 @@ namespace Kasten {
  */
 class AbstractColumnTextRenderer
 {
+private:
+    static constexpr int DefaultNoOfSublines = 1;
+
 protected:
     static QString whiteSpace(unsigned int length);
 
