@@ -28,8 +28,11 @@ namespace Kasten {
 ClipboardController::ClipboardController(KXMLGUIClient* guiClient)
 {
     mCutAction =   KStandardAction::cut(  this, &ClipboardController::cut,   this);
+    mCutAction->setEnabled(false);
     mCopyAction =  KStandardAction::copy( this, &ClipboardController::copy,  this);
+    mCopyAction->setEnabled(false);
     mPasteAction = KStandardAction::paste(this, &ClipboardController::paste, this);
+    mPasteAction->setEnabled(false);
 
     guiClient->actionCollection()->addActions({
         mCutAction,
@@ -39,8 +42,6 @@ ClipboardController::ClipboardController(KXMLGUIClient* guiClient)
 
     connect(QApplication::clipboard(), &QClipboard::dataChanged,
             this, &ClipboardController::onClipboardDataChanged);
-
-    setTargetModel(nullptr);
 }
 
 void ClipboardController::setTargetModel(AbstractModel* model)
