@@ -17,9 +17,12 @@ class AbstractConnectJobPrivate
 {
 public:
     explicit AbstractConnectJobPrivate(AbstractConnectJob* parent);
+    AbstractConnectJobPrivate(const AbstractConnectJobPrivate&) = delete;
 
     virtual ~AbstractConnectJobPrivate();
 
+    AbstractConnectJobPrivate& operator=(const AbstractConnectJobPrivate&) = delete;
+
 protected:
     AbstractConnectJob* const q_ptr;
 };
