@@ -12,6 +12,7 @@
 // Kasten
 #include <Kasten/KastenCore>
 // KF
+#include <kparts_version.h>
 #include <KParts/ReadWritePart>
 // Qt
 #include <QVector>
@@ -27,6 +28,11 @@ class AbstractXmlGuiController;
 class AbstractXmlGuiControllerFactory;
 class AbstractDocument;
 }
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+class KPluginMetaData;
+#else
+class KAboutData;
+#endif
 class QVBoxLayout;
 
 class OktetaPart : public KParts::ReadWritePart
@@ -45,7 +51,11 @@ public:
 
 public:
     OktetaPart(QObject* parent,
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+               const KPluginMetaData& metaData,
+#else
                const KAboutData& componentData,
+#endif
                Modus modus,
                Kasten::ByteArrayViewProfileManager* viewProfileManager,
                Kasten::ModelCodecManager* modelCodecManager,
